<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
    >
      <el-form-item label="预约日期" prop="createTimeList">
        <el-date-picker
          v-model="createTimeList"
          type="datetimerange"
          align="right"
          :picker-options="pickerOptions"
          style="width: 300px"
          start-placeholder="开始日期"
          end-placeholder="结束日期"
          :default-time="['00:00:00', '23:59:00']"
          format="yyyy-MM-dd HH:mm"
          value-format="yyyy-MM-dd HH:mm"
          @change="dateChangebirthday1"
        >
        </el-date-picker>
      </el-form-item>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['mall:timeConfig:add']"
          >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="primary"
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['mall:timeConfig:edit']"
          >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="primary"
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['mall:timeConfig:remove']"
          >删除
        </el-button>
      </el-col>
      <!-- <el-col :span="1.5">
        <el-button
          type="primary"
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['mall:timeConfig:export']"
          >导出
        </el-button>
      </el-col> -->
      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-table
      border
      v-loading="loading"
      :data="timeConfigList"
      @selection-change="handleSelectionChange"
    >
      <el-table-column type="selection" width="50" align="center" />
      <el-table-column label="序号" width="55" align="center" prop="newID" />
      <el-table-column label="日期" align="center" prop="time" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.time, "{y}-{m}-{d}") }}</span>
        </template>
      </el-table-column>
      <el-table-column label="总数" align="center" prop="allNum" width="100" />
      <el-table-column label="余数" align="center" prop="nowNum" width="100" />
      <el-table-column label="备注" align="center" prop="remark" />
      <el-table-column
        width="80"
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
      >
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['mall:timeConfig:edit']"
            title="修改"
          >
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['mall:timeConfig:remove']"
            title="删除"
          >
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <div class="pag">
      <div class="pag1">
        <pagination
          v-show="total > 0"
          :total="total"
          :page.sync="queryParams.pageNum"
          :limit.sync="queryParams.pageSize"
          @pagination="getList"
        />
      </div>
    </div>

    <!-- 添加或修改预约时间对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="570px" append-to-body>
      <el-form
        ref="form"
        :model="form"
        :rules="rules"
        label-width="50px"
        :inline="true"
      >
        <!-- <el-form-item>
          <el-radio-group v-model="radio" @change="danxuan">
            <el-radio v-model="radio" label="3">单天</el-radio>
            <el-radio v-model="radio" label="6">区间</el-radio>
          </el-radio-group>
        </el-form-item> -->

        <div style="display: flex" v-show="yc">
          <el-form-item label="日期" prop="startTime">
            <el-date-picker
              disabled
              clearable
              v-model="form.startTime"
              type="date"
              value-format="yyyy-MM-dd"
              placeholder="请选择开始日期"
            >
            </el-date-picker>
          </el-form-item>
          <span style="margin-top: 10px; margin-right: 8px">~</span>
          <el-form-item prop="endTime">
            <el-date-picker
              clearable
              v-model="form.endTime"
              type="date"
              value-format="yyyy-MM-dd"
              placeholder="请选择结束日期"
            >
            </el-date-picker>
          </el-form-item>
        </div>

        <el-form-item label="总数" prop="allNum">
          <el-input
            v-model="form.allNum"
            placeholder="请输入总数"
            style="width: 465px"
          /> </el-form-item
        ><br />
        <el-form-item label="余数" prop="nowNum">
          <el-input
            v-model="form.nowNum"
            placeholder="请输入余数"
            style="width: 465px"
            @input="numchange"
          />
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input
            v-model="form.remark"
            placeholder="请输入备注"
            style="width: 465px"
          />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm" :disabled="disabled"
          >确 定</el-button
        >
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listTimeConfig,
  getTimeConfig,
  delTimeConfig,
  addTimeConfig,
  updateTimeConfig,
  isExist,
  returnLastTime,
} from "@/api/mall/timeConfig";
import {
  getNumber,
  hasReport,
  getPdf,
  getOrderList,
  getNewDateList,
} from "@/api/hosp/order";
import moment from "moment";
export default {
  name: "TimeConfig",
  data() {
    let checkPhoneNum = (rule, value, callback) => {
      console.log(value);
      let patter = new RegExp(/^1\s*[3456789]\s*(\d\s*){9}$/);
      if (value == "" && value == undefined && !value) {
        return callback("");
      } else if (value != undefined && value != "") {
        return callback();
      } else if (!patter.test(value)) {
        return callback("");
      }
    };
    return {
      yc: false,
      pickerOptions: {
        disabledDate: (date) => {
          return date.getTime() < Date.now();
        },
      },
      time: "",
      jieshu: false,
      radio: "3",
      disabled: false,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 预约时间表格数据
      timeConfigList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        startTime: null,
        endTime: null,
        pageNum: 1,
        pageSize: 10,
      },
      createTimeList: [],
      startTime: "",
      pickerOptions: {
        shortcuts: [
          {
            text: "最近一周",
            onClick(picker) {
              const end = new Date();
              const start = new Date(new Date().setHours(0, 0, 0, 0));
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
              picker.$emit("pick", [start, end]);
            },
          },
          {
            text: "最近一个月",
            onClick(picker) {
              const end = new Date();
              const start = new Date(new Date().setHours(0, 0, 0, 0));
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
              picker.$emit("pick", [start, end]);
            },
          },
          {
            text: "最近三个月",
            onClick(picker) {
              const end = new Date();
              const start = new Date(new Date().setHours(0, 0, 0, 0));
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 90);
              picker.$emit("pick", [start, end]);
            },
          },
        ],
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        startTime: [
          {
            required: true,
            validator: checkPhoneNum,
            trigger: "blur",
          },
        ],
        endTime: [
          {
            required: true,
            validator: checkPhoneNum,
            trigger: "blur",
          },
        ],
        allNum: [
          {
            required: true,
            validator: checkPhoneNum,
            trigger: "blur",
          },
        ],
        nowNum: [
          {
            required: true,
            validator: checkPhoneNum,
            trigger: "blur",
          },
        ],
        deleted: [
          {
            required: true,
            validator: checkPhoneNum,
            trigger: "blur",
          },
        ],
      },
    };
  },
  created() {
    // this.getNowTime();
    
    this.getdate();
  },
  methods: {
    getdate() {
      getNewDateList().then((res) => {
        this.createTimeList = [
            moment(res.data).format("YYYY-MM-DD 00:00:00"),
            moment(res.data).format("YYYY-MM-DD 23:59:00")
          ];;
          this.getList();
      });
    },
    // / 处理默认选中当前日期
    getNowTime() {
      var curDate = new Date().getTime();
      var dayNum = 7 * 24 * 3600 * 1000;
      var threeDays = curDate - dayNum;
      var sDay = this.getLocalTime(threeDays);
      var end = this.getLocalTime(curDate);
      this.createTimeList = [sDay, end];
    },
    add0(m) {
      return m < 10 ? "0" + m : m;
    },
    getLocalTime(nS) {
      var time = new Date(nS);
      var y = time.getFullYear();
      var m = time.getMonth() + 1;
      var d = time.getDate();
      // var h = time.getHours();
      // var mm = time.getMinutes();
      return y + "-" + this.add0(m) + "-" + this.add0(d);
    },
    dateChangebirthday1(val) {
      if (val == null) {
        this.createTimeList = [];
      } else {
        this.createTimeList = val;
      }
    },
    /** 查询预约时间列表 */
    getList() {
      this.loading = true;
      if (this.createTimeList) {
        this.queryParams.startTime = this.createTimeList[0];
        this.queryParams.endTime = this.createTimeList[1];
      }
      listTimeConfig(this.queryParams).then((response) => {
        response.rows.forEach((item, index) => {
          item.newID =
            (this.queryParams.pageNum - 1) * this.queryParams.pageSize +
            index +
            1;
        });
        this.timeConfigList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // riqi(val) {
    //   let time = val.toString();
    //   isExist(time).then((res) => {
    //     if (res.data == 1) {
    //       this.$modal.msgError(`该时间段已存在`);
    //       this.disabled = true;
    //     } else {
    //       this.disabled = false;
    //     }
    //   });
    // },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        time: null,
        startTime: null,
        endTime: null,
        allNum: null,
        nowNum: null,
        createTime: null,
        createBy: null,
        updateTime: null,
        updateBy: null,
        deleted: null,
        remark: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.createTimeList = [];
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.yc = true;
      returnLastTime().then((res) => {
        this.time = res.data;
        this.form.startTime = res.data;
      });
      this.reset();
      this.open = true;
      this.title = "添加预约时间";
    },

    numchange() {
      if (this.form.allNum < this.form.nowNum) {
        this.$modal.msgError("余数不可大于总数");
      }
    },
    // danxuan() {
    //   if (this.radio == 3) {
    //     this.jieshu = false;
    //   } else {
    //     this.jieshu = true;
    //   }
    // },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.yc = false;
      this.reset();
      const id = row.id || this.ids;
      getTimeConfig(id).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改预约时间";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.id != null) {
            updateTimeConfig(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addTimeConfig(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal
        .confirm('是否确认删除预约时间编号为"' + ids + '"的数据项？')
        .then(function () {
          return delTimeConfig(ids);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
  },
};
</script>
<style scoped>
.pag {
  width: 100%;
  display: flex;
  justify-content: center;
}

.pag1 {
  width: 20%;
}
</style>
